@@ -8,6 +8,7 @@ from .DDDataGrid import DDDataGrid
 from .DataGrid import DataGrid
 from .DateBox import DateBox
 from .Drawer import Drawer
+from .DropDownButton import DropDownButton
 from .FileUploader import FileUploader
 from .Form import Form
 from .FormButtonItem import FormButtonItem
@@ -49,6 +50,7 @@ __all__ = [
     "DataGrid",
     "DateBox",
     "Drawer",
+    "DropDownButton",
     "FileUploader",
     "Form",
     "FormButtonItem",
